BODY {
   background-color: white;
}

H1 {
    font-family: sans-serif;
    font-size: 16pt;
    font-style: italic;
    color: red;
}

H2 {
   font-family: sans-serif;
   font-style: italic;
}

TR.title {
   font-family: sans-serif;
   background-color: #FFE89B;
}

TR.normal {
    font-family: sans-serif;
    background-color: white;
    padding: 0;
    margin: 0;
}

TR.highlight {
    font-family: sans-serif;
    background-color: rgb(200,255,255);
    padding: 0;
    margin: 0;
}

.directory {
   font-family: sans-serif;
   font-weight: bold;
}

.subdirectory {
   font-family: sans-serif;
   font-size: 12pt;
   font-weight: bold;
}

.subdirbuttons {
   font-family: sans-serif;
   font-size: 10pt;
}

IMG.subdir {
  vertical-align: middle;
}

P {
   font-family: sans-serif;
   background-color: transparent;
}

A {
   font-family: sans-serif;
   background-color: transparent;
}

INPUT {
    font-family: sans-serif;
    background-color: white;
}

DIV  {
  font-family: sans-serif;
  background-color: white;
}

ADDRESS {
  font-family: sans-serif;
}

.playlist {
  background-color: #FFE89B;
}
A.playlist {
  background-color: transparent;
  font-style: italic;
}
